<a name="readme-top"></a>

<div align="center">

[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]

</div>

<br />
<div align="center">
  <a href="https://github.com/aubravo/arbutus">
    <img src="docs/images/seeding.png" alt="seedling" width="120" height="120">
  </a>
<h1 align="center">arbutus</h1>
  <p align="center">
        Simplification of CLI construction in Python based on argparse: just add branches and arguments. CLI construction from yaml file also available.
    <br />
    <br />
        If you are interested in participating, please feel free to contribute.
    <br />
    <br />
    <a href="https://github.com/aubravo/arbutus"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/aubravo/arbutus/issues">Report Bug</a>
    <a href="https://github.com/aubravo/arbutus/issues">Request Feature</a>
  </p>
</div>

## Contents
* [About The Project](#about-the-project)
  * [Built With](#built-with)
* [Getting Started](#getting-started)
  * [Prerequisites](#prerequisites)
  * [Installation](#installation)
* [Usage](#usage)
  * [Useful commands](#useful-commands)
* [Roadmap](#roadmap)
* [Contributing](#contributing)
* [License](#license)
* [Contact](#contact)
* [Acknowledgments](#acknowledgments)
<!-- TOC -->

## About The Project

To Do

<p align="right">(<a href="#readme-top">back to top</a>)</p>

### Built With

[![Python][Python.org]][Python-url]

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Getting Started

### Prerequisites

To-Do

### Installation 

To-Do

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Usage

To-Do

<p align="right">(<a href="#readme-top">back to top</a>)</p>

### Useful commands: ###

To-Do

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Roadmap

See the [open issues](https://github.com/aubravo/arbutus/issues) for a full list of proposed features (and known issues).

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## License

Distributed under the MIT License. See `LICENSE` for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Contact

Alvaro U. Bravo - [alvaroubravo@gmail.com](mailto:alvaroubravo@gmail.com)

Project Links:
* [arbutus - GitHub](https://github.com/aubravo/arbutus)

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Acknowledgments

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- MARKDOWN LINKS & IMAGES -->
[contributors-shield]: https://img.shields.io/github/contributors/aubravo/arbutus.svg?style=for-the-badge
[contributors-url]: https://github.com/aubravo/arbutus/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/aubravo/arbutus.svg?style=for-the-badge
[forks-url]: https://github.com/aubravo/arbutus/network/members
[stars-shield]: https://img.shields.io/github/stars/aubravo/arbutus.svg?style=for-the-badge
[stars-url]: https://github.com/aubravo/arbutus/stargazers
[issues-shield]: https://img.shields.io/github/issues/aubravo/arbutus.svg?style=for-the-badge
[issues-url]: https://github.com/aubravo/arbutus/issues
[license-shield]: https://img.shields.io/github/license/aubravo/arbutus.svg?style=for-the-badge
[license-url]: https://github.com/aubravo/arbutus/blob/master/LICENSE
[Python.org]: https://img.shields.io/badge/Python3-4B8BBE?style=for-the-badge&logo=Python&logoColor=FFD43B
[Python-url]: https://python.org